@@ -26,11 +26,10 @@ package org.codehaus.mojo.buildhelper;
 
 import org.apache.maven.artifact.versioning.ArtifactVersion;
 import org.apache.maven.artifact.versioning.DefaultArtifactVersion;
-import org.apache.maven.plugin.AbstractMojo;
 import org.apache.maven.plugin.MojoExecutionException;
-import org.apache.maven.project.MavenProject;
-
-import java.util.Properties;
+import org.apache.maven.plugins.annotations.LifecyclePhase;
+import org.apache.maven.plugins.annotations.Mojo;
+import org.apache.maven.plugins.annotations.Parameter;
 
 /**
  * Parse a version string and set properties containing the component parts of the version.  This mojo sets the
@@ -54,37 +53,24 @@ import java.util.Properties;
  * For example, 1.0.2-beta-1 will be converted to 1.0.2.beta-1
  *
  * @author pgier
- * @version $Id: ParseVersionMojo.java 14202 2011-06-21 20:50:25Z rfscholte $
- * @goal parse-version
- * @phase validate
+ * @version $Id: ParseVersionMojo.java 17589 2012-09-23 10:08:45Z hboutemy $
  * @since 1.3
- * @threadSafe
  */
+@Mojo( name = "parse-version", defaultPhase = LifecyclePhase.VALIDATE, threadSafe = true )
 public class ParseVersionMojo
-    extends AbstractMojo
+    extends AbstractDefinePropertyMojo
 {
 
-    /**
-     * The Maven project.
-     *
-     * @parameter expression="${project}"
-     * @required
-     * @readonly
-     */
-    private MavenProject project;
-
     /**
      * The version string to parse.
-     *
-     * @parameter default-value="${project.version}"
      */
+    @Parameter( defaultValue = "${project.version}" )
     private String versionString;
 
     /**
      * Prefix string to use for the set of version properties.
-     *
-     * @parameter default-value="parsedVersion"
      */
+    @Parameter( defaultValue = "parsedVersion" )
     private String propertyPrefix;
 
     /**
@@ -94,51 +80,54 @@ public class ParseVersionMojo
      */
     public void execute()
     {
-        parseVersion (versionString, project.getProperties() );
+        parseVersion( versionString );
+    }
+
+    private void defineVersionProperty( String name, String value )
+    {
+        defineProperty( propertyPrefix + '.' + name, value );
+    }
+
+    private void defineVersionProperty( String name, int value )
+    {
+        defineVersionProperty( name, Integer.toString( value ) );
     }
 
     /**
      * Parse a version String and add the components to a properties object.
      *
      * @param version the version to parse
-     * @param props the target for the new properties
      */
-    public void parseVersion( String version, Properties props)
+    public void parseVersion( String version )
     {
         ArtifactVersion artifactVersion = new DefaultArtifactVersion( version );
 
-        if ( artifactVersion.getQualifier() != null && artifactVersion.getQualifier().equals( version ) )
+        if ( version.equals( artifactVersion.getQualifier() ) )
         {
             // This means the version parsing failed, so try osgi format.
-            getLog().debug("The version is not in the regular format, will try OSGi format instead");
+            getLog().debug( "The version is not in the regular format, will try OSGi format instead" );
             artifactVersion = new OsgiArtifactVersion( version );
         }
-        props.setProperty( propertyPrefix + ".majorVersion", 
-                           Integer.toString( artifactVersion.getMajorVersion() ) );
-        props.setProperty( propertyPrefix + ".minorVersion", 
-                           Integer.toString( artifactVersion.getMinorVersion() ) );
-        props.setProperty( propertyPrefix + ".incrementalVersion",
-                           Integer.toString( artifactVersion.getIncrementalVersion() ) );
 
-        props.setProperty( propertyPrefix + ".nextMajorVersion", 
-                           Integer.toString( artifactVersion.getMajorVersion() + 1 ) );
-        props.setProperty( propertyPrefix + ".nextMinorVersion", 
-                           Integer.toString( artifactVersion.getMinorVersion() + 1 ) );
-        props.setProperty( propertyPrefix + ".nextIncrementalVersion",
-                           Integer.toString( artifactVersion.getIncrementalVersion() + 1 ) );
+        defineVersionProperty( "majorVersion", artifactVersion.getMajorVersion() );
+        defineVersionProperty( "minorVersion", artifactVersion.getMinorVersion() );
+        defineVersionProperty( "incrementalVersion", artifactVersion.getIncrementalVersion() );
+        defineVersionProperty( "nextMajorVersion", artifactVersion.getMajorVersion() + 1 );
+        defineVersionProperty( "nextMinorVersion", artifactVersion.getMinorVersion() + 1 );
+        defineVersionProperty( "nextIncrementalVersion", artifactVersion.getIncrementalVersion() + 1 );
 
         String qualifier = artifactVersion.getQualifier();
-        if (qualifier == null)
+        if ( qualifier == null )
         {
             qualifier = "";
         }
-        props.setProperty( propertyPrefix + ".qualifier", qualifier );
+        defineVersionProperty( "qualifier", qualifier );
 
-        props.setProperty( propertyPrefix + ".buildNumber", Integer.toString( artifactVersion.getBuildNumber() ) );
+        defineVersionProperty( "buildNumber", artifactVersion.getBuildNumber() );
 
         // Replace the first instance of "-" to create an osgi compatible version string.
         String osgiVersion = getOsgiVersion( artifactVersion );
-        props.setProperty( propertyPrefix + ".osgiVersion", osgiVersion );
+        defineVersionProperty( "osgiVersion", osgiVersion );
     }
 
     public void setPropertyPrefix( String prefix )
@@ -153,7 +142,7 @@ public class ParseVersionMojo
      */
     public String getOsgiVersion( ArtifactVersion version )
     {
-        if ( version.toString().equals( version.getQualifier() ))
+        if ( version.toString().equals( version.getQualifier() ) )
         {
             return version.toString();
         }
@@ -162,18 +151,21 @@ public class ParseVersionMojo
         osgiVersion.append( version.getMajorVersion() );
         osgiVersion.append( "." + version.getMinorVersion() );
         osgiVersion.append( "." + version.getIncrementalVersion() );
+
         if ( version.getQualifier() != null || version.getBuildNumber() != 0 )
         {
             osgiVersion.append( "." );
+
+            if ( version.getQualifier() != null )
+            {
+                osgiVersion.append( version.getQualifier() );
+            }
+            if ( version.getBuildNumber() != 0 )
+            {
+                osgiVersion.append( version.getBuildNumber() );
+            }
         }
-        if ( version.getQualifier() != null )
-        {
-            osgiVersion.append( version.getQualifier() );
-        }
-        if ( version.getBuildNumber() != 0 )
-        {
-            osgiVersion.append( version.getBuildNumber() );
-        }
+
         return osgiVersion.toString();
     }
 }
